# AnyDI Django

<section align="center">

<i>AnyDI Django extension.</i>

<p>
  <a href="https://github.com/antonrh/anydi_django/actions/workflows/ci.yml" target="_blank">
    <img src="https://github.com/antonrh/anydi_django/actions/workflows/ci.yml/badge.svg" alt="Build Status">
  </a>
  <a href="https://codecov.io/gh/antonrh/anydi_django" target="_blank">
    <img src="https://codecov.io/gh/antonrh/anydi_django/branch/main/graph/badge.svg?token=67CLD19I0C" alt="Coverage Status">
  </a>
  <a href="https://anydi.readthedocs.io/en/stable/extensions/django/?badge=latest" target="_blank">
    <img src="https://anydi.readthedocs.io/en/stable/extensions/django/badge/?version=latest" alt="Documentation Status">
  </a>
</p>

</section>

---

## 📘 Overview

**AnyDI Django** is an official extension for integrating [AnyDI](https://github.com/antonrh/anydi) — a lightweight dependency injection framework — into Django projects.

---

## 📖 Documentation

Full documentation is available here:

🔗 [https://anydi.readthedocs.io/en/stable/extensions/django/](https://anydi.readthedocs.io/en/stable/extensions/django/)

---

## ⚙️ Installation

```bash
pip install anydi[django]
```

or 

```bash
pip install anydi-django
```
